import datetime
from http import HTTPStatus
from typing import Any, Optional, Union
from uuid import UUID

import httpx

from ...client import AuthenticatedClient, Client
from ...models.standing_list_fixture_type import StandingListFixtureType
from ...models.standing_list_grouping_base import StandingListGroupingBase
from ...models.standing_list_grouping_conference_division import StandingListGroupingConferenceDivision
from ...models.standing_list_grouping_stage_pool import StandingListGroupingStagePool
from ...models.standing_list_response_default import StandingListResponseDefault
from ...models.standing_list_standings_response import StandingListStandingsResponse
from ...types import UNSET, Response, Unset


def _get_kwargs(
    organization_id: str,
    season_id: UUID,
    *,
    added: Union[Unset, datetime.datetime] = UNSET,
    conference_id: Union[Unset, UUID] = UNSET,
    division_id: Union[Unset, UUID] = UNSET,
    entity_id: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_type: Union[Unset, StandingListFixtureType] = UNSET,
    grouping_base: Union[Unset, StandingListGroupingBase] = UNSET,
    grouping_conference_division: Union[Unset, StandingListGroupingConferenceDivision] = UNSET,
    grouping_stage_pool: Union[Unset, StandingListGroupingStagePool] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    in_progress: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    latest: Union[Unset, bool] = UNSET,
    limit: Union[Unset, int] = 10,
    live: Union[Unset, bool] = UNSET,
    offset: Union[Unset, int] = UNSET,
    pool_code: Union[Unset, str] = UNSET,
    round_code: Union[Unset, str] = UNSET,
    round_number: Union[Unset, str] = UNSET,
    sort_by: Union[Unset, str] = UNSET,
    stage_code: Union[Unset, str] = UNSET,
    standing_configuration_id: Union[Unset, UUID] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    json_added: Union[Unset, str] = UNSET
    if not isinstance(added, Unset):
        json_added = added.isoformat()
    params["added"] = json_added

    json_conference_id: Union[Unset, str] = UNSET
    if not isinstance(conference_id, Unset):
        json_conference_id = str(conference_id)
    params["conferenceId"] = json_conference_id

    json_division_id: Union[Unset, str] = UNSET
    if not isinstance(division_id, Unset):
        json_division_id = str(division_id)
    params["divisionId"] = json_division_id

    json_entity_id: Union[Unset, str] = UNSET
    if not isinstance(entity_id, Unset):
        json_entity_id = str(entity_id)
    params["entityId"] = json_entity_id

    params["external"] = external

    params["fields"] = fields

    json_fixture_type: Union[Unset, str] = UNSET
    if not isinstance(fixture_type, Unset):
        json_fixture_type = fixture_type.value

    params["fixtureType"] = json_fixture_type

    json_grouping_base: Union[Unset, str] = UNSET
    if not isinstance(grouping_base, Unset):
        json_grouping_base = grouping_base.value

    params["groupingBase"] = json_grouping_base

    json_grouping_conference_division: Union[Unset, str] = UNSET
    if not isinstance(grouping_conference_division, Unset):
        json_grouping_conference_division = grouping_conference_division.value

    params["groupingConferenceDivision"] = json_grouping_conference_division

    json_grouping_stage_pool: Union[Unset, str] = UNSET
    if not isinstance(grouping_stage_pool, Unset):
        json_grouping_stage_pool = grouping_stage_pool.value

    params["groupingStagePool"] = json_grouping_stage_pool

    params["hideNull"] = hide_null

    params["inProgress"] = in_progress

    params["include"] = include

    params["latest"] = latest

    params["limit"] = limit

    params["live"] = live

    params["offset"] = offset

    params["poolCode"] = pool_code

    params["roundCode"] = round_code

    params["roundNumber"] = round_number

    params["sortBy"] = sort_by

    params["stageCode"] = stage_code

    json_standing_configuration_id: Union[Unset, str] = UNSET
    if not isinstance(standing_configuration_id, Unset):
        json_standing_configuration_id = str(standing_configuration_id)
    params["standingConfigurationId"] = json_standing_configuration_id

    json_updated: Union[Unset, str] = UNSET
    if not isinstance(updated, Unset):
        json_updated = updated.isoformat()
    params["updated"] = json_updated

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": f"/handball/o/{organization_id}/seasons/{season_id}/standings",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Union[StandingListResponseDefault, StandingListStandingsResponse]:
    if response.status_code == 200:
        response_200 = StandingListStandingsResponse.from_dict(response.json())

        return response_200

    response_default = StandingListResponseDefault.from_dict(response.json())

    return response_default


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[StandingListResponseDefault, StandingListStandingsResponse]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    organization_id: str,
    season_id: UUID,
    *,
    client: Union[AuthenticatedClient, Client],
    added: Union[Unset, datetime.datetime] = UNSET,
    conference_id: Union[Unset, UUID] = UNSET,
    division_id: Union[Unset, UUID] = UNSET,
    entity_id: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_type: Union[Unset, StandingListFixtureType] = UNSET,
    grouping_base: Union[Unset, StandingListGroupingBase] = UNSET,
    grouping_conference_division: Union[Unset, StandingListGroupingConferenceDivision] = UNSET,
    grouping_stage_pool: Union[Unset, StandingListGroupingStagePool] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    in_progress: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    latest: Union[Unset, bool] = UNSET,
    limit: Union[Unset, int] = 10,
    live: Union[Unset, bool] = UNSET,
    offset: Union[Unset, int] = UNSET,
    pool_code: Union[Unset, str] = UNSET,
    round_code: Union[Unset, str] = UNSET,
    round_number: Union[Unset, str] = UNSET,
    sort_by: Union[Unset, str] = UNSET,
    stage_code: Union[Unset, str] = UNSET,
    standing_configuration_id: Union[Unset, UUID] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
) -> Response[Union[StandingListResponseDefault, StandingListStandingsResponse]]:
    """Get a list of standings

     Return a list of available standings for a season

    Args:
        organization_id (str):  Example: b1a23.
        season_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        added (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:10:48.
        conference_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        division_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        fixture_type (Union[Unset, StandingListFixtureType]):  Example: REGULAR.
        grouping_base (Union[Unset, StandingListGroupingBase]):  Example: OVERALL.
        grouping_conference_division (Union[Unset, StandingListGroupingConferenceDivision]):
            Example: OVERALL.
        grouping_stage_pool (Union[Unset, StandingListGroupingStagePool]):  Example: OVERALL.
        hide_null (Union[Unset, bool]):  Example: True.
        in_progress (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        latest (Union[Unset, bool]):  Example: True.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        live (Union[Unset, bool]):  Example: True.
        offset (Union[Unset, int]):  Example: 10.
        pool_code (Union[Unset, str]):  Example: P1.
        round_code (Union[Unset, str]):  Example: RN1.
        round_number (Union[Unset, str]):  Example: 1.
        sort_by (Union[Unset, str]):  Example: conferenceId,divisionId,-position.
        stage_code (Union[Unset, str]):  Example: ST1.
        standing_configuration_id (Union[Unset, UUID]):  Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        updated (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:11:48.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[StandingListResponseDefault, StandingListStandingsResponse]]
    """

    kwargs = _get_kwargs(
        organization_id=organization_id,
        season_id=season_id,
        added=added,
        conference_id=conference_id,
        division_id=division_id,
        entity_id=entity_id,
        external=external,
        fields=fields,
        fixture_type=fixture_type,
        grouping_base=grouping_base,
        grouping_conference_division=grouping_conference_division,
        grouping_stage_pool=grouping_stage_pool,
        hide_null=hide_null,
        in_progress=in_progress,
        include=include,
        latest=latest,
        limit=limit,
        live=live,
        offset=offset,
        pool_code=pool_code,
        round_code=round_code,
        round_number=round_number,
        sort_by=sort_by,
        stage_code=stage_code,
        standing_configuration_id=standing_configuration_id,
        updated=updated,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    organization_id: str,
    season_id: UUID,
    *,
    client: Union[AuthenticatedClient, Client],
    added: Union[Unset, datetime.datetime] = UNSET,
    conference_id: Union[Unset, UUID] = UNSET,
    division_id: Union[Unset, UUID] = UNSET,
    entity_id: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_type: Union[Unset, StandingListFixtureType] = UNSET,
    grouping_base: Union[Unset, StandingListGroupingBase] = UNSET,
    grouping_conference_division: Union[Unset, StandingListGroupingConferenceDivision] = UNSET,
    grouping_stage_pool: Union[Unset, StandingListGroupingStagePool] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    in_progress: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    latest: Union[Unset, bool] = UNSET,
    limit: Union[Unset, int] = 10,
    live: Union[Unset, bool] = UNSET,
    offset: Union[Unset, int] = UNSET,
    pool_code: Union[Unset, str] = UNSET,
    round_code: Union[Unset, str] = UNSET,
    round_number: Union[Unset, str] = UNSET,
    sort_by: Union[Unset, str] = UNSET,
    stage_code: Union[Unset, str] = UNSET,
    standing_configuration_id: Union[Unset, UUID] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
) -> Optional[Union[StandingListResponseDefault, StandingListStandingsResponse]]:
    """Get a list of standings

     Return a list of available standings for a season

    Args:
        organization_id (str):  Example: b1a23.
        season_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        added (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:10:48.
        conference_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        division_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        fixture_type (Union[Unset, StandingListFixtureType]):  Example: REGULAR.
        grouping_base (Union[Unset, StandingListGroupingBase]):  Example: OVERALL.
        grouping_conference_division (Union[Unset, StandingListGroupingConferenceDivision]):
            Example: OVERALL.
        grouping_stage_pool (Union[Unset, StandingListGroupingStagePool]):  Example: OVERALL.
        hide_null (Union[Unset, bool]):  Example: True.
        in_progress (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        latest (Union[Unset, bool]):  Example: True.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        live (Union[Unset, bool]):  Example: True.
        offset (Union[Unset, int]):  Example: 10.
        pool_code (Union[Unset, str]):  Example: P1.
        round_code (Union[Unset, str]):  Example: RN1.
        round_number (Union[Unset, str]):  Example: 1.
        sort_by (Union[Unset, str]):  Example: conferenceId,divisionId,-position.
        stage_code (Union[Unset, str]):  Example: ST1.
        standing_configuration_id (Union[Unset, UUID]):  Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        updated (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:11:48.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[StandingListResponseDefault, StandingListStandingsResponse]
    """

    return sync_detailed(
        organization_id=organization_id,
        season_id=season_id,
        client=client,
        added=added,
        conference_id=conference_id,
        division_id=division_id,
        entity_id=entity_id,
        external=external,
        fields=fields,
        fixture_type=fixture_type,
        grouping_base=grouping_base,
        grouping_conference_division=grouping_conference_division,
        grouping_stage_pool=grouping_stage_pool,
        hide_null=hide_null,
        in_progress=in_progress,
        include=include,
        latest=latest,
        limit=limit,
        live=live,
        offset=offset,
        pool_code=pool_code,
        round_code=round_code,
        round_number=round_number,
        sort_by=sort_by,
        stage_code=stage_code,
        standing_configuration_id=standing_configuration_id,
        updated=updated,
    ).parsed


async def asyncio_detailed(
    organization_id: str,
    season_id: UUID,
    *,
    client: Union[AuthenticatedClient, Client],
    added: Union[Unset, datetime.datetime] = UNSET,
    conference_id: Union[Unset, UUID] = UNSET,
    division_id: Union[Unset, UUID] = UNSET,
    entity_id: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_type: Union[Unset, StandingListFixtureType] = UNSET,
    grouping_base: Union[Unset, StandingListGroupingBase] = UNSET,
    grouping_conference_division: Union[Unset, StandingListGroupingConferenceDivision] = UNSET,
    grouping_stage_pool: Union[Unset, StandingListGroupingStagePool] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    in_progress: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    latest: Union[Unset, bool] = UNSET,
    limit: Union[Unset, int] = 10,
    live: Union[Unset, bool] = UNSET,
    offset: Union[Unset, int] = UNSET,
    pool_code: Union[Unset, str] = UNSET,
    round_code: Union[Unset, str] = UNSET,
    round_number: Union[Unset, str] = UNSET,
    sort_by: Union[Unset, str] = UNSET,
    stage_code: Union[Unset, str] = UNSET,
    standing_configuration_id: Union[Unset, UUID] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
) -> Response[Union[StandingListResponseDefault, StandingListStandingsResponse]]:
    """Get a list of standings

     Return a list of available standings for a season

    Args:
        organization_id (str):  Example: b1a23.
        season_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        added (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:10:48.
        conference_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        division_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        fixture_type (Union[Unset, StandingListFixtureType]):  Example: REGULAR.
        grouping_base (Union[Unset, StandingListGroupingBase]):  Example: OVERALL.
        grouping_conference_division (Union[Unset, StandingListGroupingConferenceDivision]):
            Example: OVERALL.
        grouping_stage_pool (Union[Unset, StandingListGroupingStagePool]):  Example: OVERALL.
        hide_null (Union[Unset, bool]):  Example: True.
        in_progress (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        latest (Union[Unset, bool]):  Example: True.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        live (Union[Unset, bool]):  Example: True.
        offset (Union[Unset, int]):  Example: 10.
        pool_code (Union[Unset, str]):  Example: P1.
        round_code (Union[Unset, str]):  Example: RN1.
        round_number (Union[Unset, str]):  Example: 1.
        sort_by (Union[Unset, str]):  Example: conferenceId,divisionId,-position.
        stage_code (Union[Unset, str]):  Example: ST1.
        standing_configuration_id (Union[Unset, UUID]):  Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        updated (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:11:48.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[StandingListResponseDefault, StandingListStandingsResponse]]
    """

    kwargs = _get_kwargs(
        organization_id=organization_id,
        season_id=season_id,
        added=added,
        conference_id=conference_id,
        division_id=division_id,
        entity_id=entity_id,
        external=external,
        fields=fields,
        fixture_type=fixture_type,
        grouping_base=grouping_base,
        grouping_conference_division=grouping_conference_division,
        grouping_stage_pool=grouping_stage_pool,
        hide_null=hide_null,
        in_progress=in_progress,
        include=include,
        latest=latest,
        limit=limit,
        live=live,
        offset=offset,
        pool_code=pool_code,
        round_code=round_code,
        round_number=round_number,
        sort_by=sort_by,
        stage_code=stage_code,
        standing_configuration_id=standing_configuration_id,
        updated=updated,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    organization_id: str,
    season_id: UUID,
    *,
    client: Union[AuthenticatedClient, Client],
    added: Union[Unset, datetime.datetime] = UNSET,
    conference_id: Union[Unset, UUID] = UNSET,
    division_id: Union[Unset, UUID] = UNSET,
    entity_id: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_type: Union[Unset, StandingListFixtureType] = UNSET,
    grouping_base: Union[Unset, StandingListGroupingBase] = UNSET,
    grouping_conference_division: Union[Unset, StandingListGroupingConferenceDivision] = UNSET,
    grouping_stage_pool: Union[Unset, StandingListGroupingStagePool] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    in_progress: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    latest: Union[Unset, bool] = UNSET,
    limit: Union[Unset, int] = 10,
    live: Union[Unset, bool] = UNSET,
    offset: Union[Unset, int] = UNSET,
    pool_code: Union[Unset, str] = UNSET,
    round_code: Union[Unset, str] = UNSET,
    round_number: Union[Unset, str] = UNSET,
    sort_by: Union[Unset, str] = UNSET,
    stage_code: Union[Unset, str] = UNSET,
    standing_configuration_id: Union[Unset, UUID] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
) -> Optional[Union[StandingListResponseDefault, StandingListStandingsResponse]]:
    """Get a list of standings

     Return a list of available standings for a season

    Args:
        organization_id (str):  Example: b1a23.
        season_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        added (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:10:48.
        conference_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        division_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        fixture_type (Union[Unset, StandingListFixtureType]):  Example: REGULAR.
        grouping_base (Union[Unset, StandingListGroupingBase]):  Example: OVERALL.
        grouping_conference_division (Union[Unset, StandingListGroupingConferenceDivision]):
            Example: OVERALL.
        grouping_stage_pool (Union[Unset, StandingListGroupingStagePool]):  Example: OVERALL.
        hide_null (Union[Unset, bool]):  Example: True.
        in_progress (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        latest (Union[Unset, bool]):  Example: True.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        live (Union[Unset, bool]):  Example: True.
        offset (Union[Unset, int]):  Example: 10.
        pool_code (Union[Unset, str]):  Example: P1.
        round_code (Union[Unset, str]):  Example: RN1.
        round_number (Union[Unset, str]):  Example: 1.
        sort_by (Union[Unset, str]):  Example: conferenceId,divisionId,-position.
        stage_code (Union[Unset, str]):  Example: ST1.
        standing_configuration_id (Union[Unset, UUID]):  Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        updated (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:11:48.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[StandingListResponseDefault, StandingListStandingsResponse]
    """

    return (
        await asyncio_detailed(
            organization_id=organization_id,
            season_id=season_id,
            client=client,
            added=added,
            conference_id=conference_id,
            division_id=division_id,
            entity_id=entity_id,
            external=external,
            fields=fields,
            fixture_type=fixture_type,
            grouping_base=grouping_base,
            grouping_conference_division=grouping_conference_division,
            grouping_stage_pool=grouping_stage_pool,
            hide_null=hide_null,
            in_progress=in_progress,
            include=include,
            latest=latest,
            limit=limit,
            live=live,
            offset=offset,
            pool_code=pool_code,
            round_code=round_code,
            round_number=round_number,
            sort_by=sort_by,
            stage_code=stage_code,
            standing_configuration_id=standing_configuration_id,
            updated=updated,
        )
    ).parsed



from enum import Enum


class ImagesListSecondaryBaseType(str, Enum):
    COMPETITION = "COMPETITION"
    CONFERENCE = "CONFERENCE"
    DIVISION = "DIVISION"
    ENTITY = "ENTITY"
    ENTITYGROUP = "ENTITYGROUP"
    LEAGUE = "LEAGUE"
    ORGANIZATION = "ORGANIZATION"
    PERSON = "PERSON"
    SEASON = "SEASON"
    UNIFORM = "UNIFORM"
    UNIFORM_ITEM = "UNIFORM_ITEM"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class StandingModelGroupingConferenceDivision(str, Enum):
    CONFERENCE = "CONFERENCE"
    DIVISION = "DIVISION"
    OVERALL = "OVERALL"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.conference_external_ids_model import ConferenceExternalIdsModel
    from ..models.included_data import IncludedData
    from ..models.response_links import ResponseLinks
    from ..models.response_meta_data import ResponseMetaData


T = TypeVar("T", bound="ConferenceExternalIdsListConferenceExternalIdsResponse")


@_attrs_define
class ConferenceExternalIdsListConferenceExternalIdsResponse:
    """
    Attributes:
        meta (Union[Unset, ResponseMetaData]):
        links (Union[Unset, ResponseLinks]):
        included (Union[Unset, IncludedData]): Available if the request used the 'include' parameter.  It contains extra
            data about resources found in the data block.
        data (Union[Unset, list['ConferenceExternalIdsModel']]):
    """

    meta: Union[Unset, "ResponseMetaData"] = UNSET
    links: Union[Unset, "ResponseLinks"] = UNSET
    included: Union[Unset, "IncludedData"] = UNSET
    data: Union[Unset, list["ConferenceExternalIdsModel"]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        meta: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.meta, Unset):
            meta = self.meta.to_dict()

        links: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.links, Unset):
            links = self.links.to_dict()

        included: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.included, Unset):
            included = self.included.to_dict()

        data: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.data, Unset):
            data = []
            for data_item_data in self.data:
                data_item = data_item_data.to_dict()
                data.append(data_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if meta is not UNSET:
            field_dict["meta"] = meta
        if links is not UNSET:
            field_dict["links"] = links
        if included is not UNSET:
            field_dict["included"] = included
        if data is not UNSET:
            field_dict["data"] = data

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.conference_external_ids_model import ConferenceExternalIdsModel
        from ..models.included_data import IncludedData
        from ..models.response_links import ResponseLinks
        from ..models.response_meta_data import ResponseMetaData

        d = dict(src_dict)
        _meta = d.pop("meta", UNSET)
        meta: Union[Unset, ResponseMetaData]
        if isinstance(_meta, Unset):
            meta = UNSET
        else:
            meta = ResponseMetaData.from_dict(_meta)

        _links = d.pop("links", UNSET)
        links: Union[Unset, ResponseLinks]
        if isinstance(_links, Unset):
            links = UNSET
        else:
            links = ResponseLinks.from_dict(_links)

        _included = d.pop("included", UNSET)
        included: Union[Unset, IncludedData]
        if isinstance(_included, Unset):
            included = UNSET
        else:
            included = IncludedData.from_dict(_included)

        data = []
        _data = d.pop("data", UNSET)
        for data_item_data in _data or []:
            data_item = ConferenceExternalIdsModel.from_dict(data_item_data)

            data.append(data_item)

        conference_external_ids_list_conference_external_ids_response = cls(
            meta=meta,
            links=links,
            included=included,
            data=data,
        )

        conference_external_ids_list_conference_external_ids_response.additional_properties = d
        return conference_external_ids_list_conference_external_ids_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from http import HTTPStatus
from typing import Any, Optional, Union
from uuid import UUID

import httpx

from ...client import AuthenticatedClient, Client
from ...models.video_stream_inputs_org_list_feed_type import VideoStreamInputsOrgListFeedType
from ...models.video_stream_inputs_org_list_response_default import VideoStreamInputsOrgListResponseDefault
from ...models.video_stream_inputs_org_list_video_stream_inputs_response import (
    VideoStreamInputsOrgListVideoStreamInputsResponse,
)
from ...types import UNSET, Response, Unset


def _get_kwargs(
    organization_id: str,
    *,
    added: Union[Unset, datetime.datetime] = UNSET,
    competition_id: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    feed_type: Union[Unset, VideoStreamInputsOrgListFeedType] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_id: Union[Unset, UUID] = UNSET,
    from_time_local: Union[Unset, datetime.datetime] = UNSET,
    from_time_utc: Union[Unset, datetime.datetime] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    locale: Union[Unset, str] = UNSET,
    offset: Union[Unset, int] = UNSET,
    provider: Union[Unset, str] = UNSET,
    season_id: Union[Unset, UUID] = UNSET,
    source_number: Union[Unset, int] = UNSET,
    to_time_local: Union[Unset, datetime.datetime] = UNSET,
    to_time_utc: Union[Unset, datetime.datetime] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
    venue_id: Union[Unset, UUID] = UNSET,
    video_input_id: Union[Unset, UUID] = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    json_added: Union[Unset, str] = UNSET
    if not isinstance(added, Unset):
        json_added = added.isoformat()
    params["added"] = json_added

    json_competition_id: Union[Unset, str] = UNSET
    if not isinstance(competition_id, Unset):
        json_competition_id = str(competition_id)
    params["competitionId"] = json_competition_id

    params["external"] = external

    json_feed_type: Union[Unset, str] = UNSET
    if not isinstance(feed_type, Unset):
        json_feed_type = feed_type.value

    params["feedType"] = json_feed_type

    params["fields"] = fields

    json_fixture_id: Union[Unset, str] = UNSET
    if not isinstance(fixture_id, Unset):
        json_fixture_id = str(fixture_id)
    params["fixtureId"] = json_fixture_id

    json_from_time_local: Union[Unset, str] = UNSET
    if not isinstance(from_time_local, Unset):
        json_from_time_local = from_time_local.isoformat()
    params["fromTimeLocal"] = json_from_time_local

    json_from_time_utc: Union[Unset, str] = UNSET
    if not isinstance(from_time_utc, Unset):
        json_from_time_utc = from_time_utc.isoformat()
    params["fromTimeUTC"] = json_from_time_utc

    params["hideNull"] = hide_null

    params["include"] = include

    params["limit"] = limit

    params["locale"] = locale

    params["offset"] = offset

    params["provider"] = provider

    json_season_id: Union[Unset, str] = UNSET
    if not isinstance(season_id, Unset):
        json_season_id = str(season_id)
    params["seasonId"] = json_season_id

    params["sourceNumber"] = source_number

    json_to_time_local: Union[Unset, str] = UNSET
    if not isinstance(to_time_local, Unset):
        json_to_time_local = to_time_local.isoformat()
    params["toTimeLocal"] = json_to_time_local

    json_to_time_utc: Union[Unset, str] = UNSET
    if not isinstance(to_time_utc, Unset):
        json_to_time_utc = to_time_utc.isoformat()
    params["toTimeUTC"] = json_to_time_utc

    json_updated: Union[Unset, str] = UNSET
    if not isinstance(updated, Unset):
        json_updated = updated.isoformat()
    params["updated"] = json_updated

    json_venue_id: Union[Unset, str] = UNSET
    if not isinstance(venue_id, Unset):
        json_venue_id = str(venue_id)
    params["venueId"] = json_venue_id

    json_video_input_id: Union[Unset, str] = UNSET
    if not isinstance(video_input_id, Unset):
        json_video_input_id = str(video_input_id)
    params["videoInputId"] = json_video_input_id

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": f"/handball/o/{organization_id}/video/streams/inputs",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Union[VideoStreamInputsOrgListResponseDefault, VideoStreamInputsOrgListVideoStreamInputsResponse]:
    if response.status_code == 200:
        response_200 = VideoStreamInputsOrgListVideoStreamInputsResponse.from_dict(response.json())

        return response_200

    response_default = VideoStreamInputsOrgListResponseDefault.from_dict(response.json())

    return response_default


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[VideoStreamInputsOrgListResponseDefault, VideoStreamInputsOrgListVideoStreamInputsResponse]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    organization_id: str,
    *,
    client: AuthenticatedClient,
    added: Union[Unset, datetime.datetime] = UNSET,
    competition_id: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    feed_type: Union[Unset, VideoStreamInputsOrgListFeedType] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_id: Union[Unset, UUID] = UNSET,
    from_time_local: Union[Unset, datetime.datetime] = UNSET,
    from_time_utc: Union[Unset, datetime.datetime] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    locale: Union[Unset, str] = UNSET,
    offset: Union[Unset, int] = UNSET,
    provider: Union[Unset, str] = UNSET,
    season_id: Union[Unset, UUID] = UNSET,
    source_number: Union[Unset, int] = UNSET,
    to_time_local: Union[Unset, datetime.datetime] = UNSET,
    to_time_utc: Union[Unset, datetime.datetime] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
    venue_id: Union[Unset, UUID] = UNSET,
    video_input_id: Union[Unset, UUID] = UNSET,
) -> Response[Union[VideoStreamInputsOrgListResponseDefault, VideoStreamInputsOrgListVideoStreamInputsResponse]]:
    """List available video inputs for an organization

     Display the list of video inputs for an organization. This will only display inputs for matches in
    the future and from 12 hours in the past that have not been completed/cancelled.

    Args:
        organization_id (str):  Example: b1a23.
        added (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:10:48.
        competition_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        external (Union[Unset, str]):  Example: entityId,personId.
        feed_type (Union[Unset, VideoStreamInputsOrgListFeedType]):  Example: PRIMARY.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        fixture_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        from_time_local (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        from_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        hide_null (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        locale (Union[Unset, str]):  Example: fr_FR.
        offset (Union[Unset, int]):  Example: 10.
        provider (Union[Unset, str]):  Example: Test Provider.
        season_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        source_number (Union[Unset, int]):  Example: 1.
        to_time_local (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        to_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        updated (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:11:48.
        venue_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        video_input_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[VideoStreamInputsOrgListResponseDefault, VideoStreamInputsOrgListVideoStreamInputsResponse]]
    """

    kwargs = _get_kwargs(
        organization_id=organization_id,
        added=added,
        competition_id=competition_id,
        external=external,
        feed_type=feed_type,
        fields=fields,
        fixture_id=fixture_id,
        from_time_local=from_time_local,
        from_time_utc=from_time_utc,
        hide_null=hide_null,
        include=include,
        limit=limit,
        locale=locale,
        offset=offset,
        provider=provider,
        season_id=season_id,
        source_number=source_number,
        to_time_local=to_time_local,
        to_time_utc=to_time_utc,
        updated=updated,
        venue_id=venue_id,
        video_input_id=video_input_id,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    organization_id: str,
    *,
    client: AuthenticatedClient,
    added: Union[Unset, datetime.datetime] = UNSET,
    competition_id: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    feed_type: Union[Unset, VideoStreamInputsOrgListFeedType] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_id: Union[Unset, UUID] = UNSET,
    from_time_local: Union[Unset, datetime.datetime] = UNSET,
    from_time_utc: Union[Unset, datetime.datetime] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    locale: Union[Unset, str] = UNSET,
    offset: Union[Unset, int] = UNSET,
    provider: Union[Unset, str] = UNSET,
    season_id: Union[Unset, UUID] = UNSET,
    source_number: Union[Unset, int] = UNSET,
    to_time_local: Union[Unset, datetime.datetime] = UNSET,
    to_time_utc: Union[Unset, datetime.datetime] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
    venue_id: Union[Unset, UUID] = UNSET,
    video_input_id: Union[Unset, UUID] = UNSET,
) -> Optional[Union[VideoStreamInputsOrgListResponseDefault, VideoStreamInputsOrgListVideoStreamInputsResponse]]:
    """List available video inputs for an organization

     Display the list of video inputs for an organization. This will only display inputs for matches in
    the future and from 12 hours in the past that have not been completed/cancelled.

    Args:
        organization_id (str):  Example: b1a23.
        added (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:10:48.
        competition_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        external (Union[Unset, str]):  Example: entityId,personId.
        feed_type (Union[Unset, VideoStreamInputsOrgListFeedType]):  Example: PRIMARY.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        fixture_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        from_time_local (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        from_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        hide_null (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        locale (Union[Unset, str]):  Example: fr_FR.
        offset (Union[Unset, int]):  Example: 10.
        provider (Union[Unset, str]):  Example: Test Provider.
        season_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        source_number (Union[Unset, int]):  Example: 1.
        to_time_local (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        to_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        updated (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:11:48.
        venue_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        video_input_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[VideoStreamInputsOrgListResponseDefault, VideoStreamInputsOrgListVideoStreamInputsResponse]
    """

    return sync_detailed(
        organization_id=organization_id,
        client=client,
        added=added,
        competition_id=competition_id,
        external=external,
        feed_type=feed_type,
        fields=fields,
        fixture_id=fixture_id,
        from_time_local=from_time_local,
        from_time_utc=from_time_utc,
        hide_null=hide_null,
        include=include,
        limit=limit,
        locale=locale,
        offset=offset,
        provider=provider,
        season_id=season_id,
        source_number=source_number,
        to_time_local=to_time_local,
        to_time_utc=to_time_utc,
        updated=updated,
        venue_id=venue_id,
        video_input_id=video_input_id,
    ).parsed


async def asyncio_detailed(
    organization_id: str,
    *,
    client: AuthenticatedClient,
    added: Union[Unset, datetime.datetime] = UNSET,
    competition_id: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    feed_type: Union[Unset, VideoStreamInputsOrgListFeedType] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_id: Union[Unset, UUID] = UNSET,
    from_time_local: Union[Unset, datetime.datetime] = UNSET,
    from_time_utc: Union[Unset, datetime.datetime] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    locale: Union[Unset, str] = UNSET,
    offset: Union[Unset, int] = UNSET,
    provider: Union[Unset, str] = UNSET,
    season_id: Union[Unset, UUID] = UNSET,
    source_number: Union[Unset, int] = UNSET,
    to_time_local: Union[Unset, datetime.datetime] = UNSET,
    to_time_utc: Union[Unset, datetime.datetime] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
    venue_id: Union[Unset, UUID] = UNSET,
    video_input_id: Union[Unset, UUID] = UNSET,
) -> Response[Union[VideoStreamInputsOrgListResponseDefault, VideoStreamInputsOrgListVideoStreamInputsResponse]]:
    """List available video inputs for an organization

     Display the list of video inputs for an organization. This will only display inputs for matches in
    the future and from 12 hours in the past that have not been completed/cancelled.

    Args:
        organization_id (str):  Example: b1a23.
        added (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:10:48.
        competition_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        external (Union[Unset, str]):  Example: entityId,personId.
        feed_type (Union[Unset, VideoStreamInputsOrgListFeedType]):  Example: PRIMARY.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        fixture_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        from_time_local (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        from_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        hide_null (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        locale (Union[Unset, str]):  Example: fr_FR.
        offset (Union[Unset, int]):  Example: 10.
        provider (Union[Unset, str]):  Example: Test Provider.
        season_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        source_number (Union[Unset, int]):  Example: 1.
        to_time_local (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        to_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        updated (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:11:48.
        venue_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        video_input_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[VideoStreamInputsOrgListResponseDefault, VideoStreamInputsOrgListVideoStreamInputsResponse]]
    """

    kwargs = _get_kwargs(
        organization_id=organization_id,
        added=added,
        competition_id=competition_id,
        external=external,
        feed_type=feed_type,
        fields=fields,
        fixture_id=fixture_id,
        from_time_local=from_time_local,
        from_time_utc=from_time_utc,
        hide_null=hide_null,
        include=include,
        limit=limit,
        locale=locale,
        offset=offset,
        provider=provider,
        season_id=season_id,
        source_number=source_number,
        to_time_local=to_time_local,
        to_time_utc=to_time_utc,
        updated=updated,
        venue_id=venue_id,
        video_input_id=video_input_id,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    organization_id: str,
    *,
    client: AuthenticatedClient,
    added: Union[Unset, datetime.datetime] = UNSET,
    competition_id: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    feed_type: Union[Unset, VideoStreamInputsOrgListFeedType] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_id: Union[Unset, UUID] = UNSET,
    from_time_local: Union[Unset, datetime.datetime] = UNSET,
    from_time_utc: Union[Unset, datetime.datetime] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    locale: Union[Unset, str] = UNSET,
    offset: Union[Unset, int] = UNSET,
    provider: Union[Unset, str] = UNSET,
    season_id: Union[Unset, UUID] = UNSET,
    source_number: Union[Unset, int] = UNSET,
    to_time_local: Union[Unset, datetime.datetime] = UNSET,
    to_time_utc: Union[Unset, datetime.datetime] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
    venue_id: Union[Unset, UUID] = UNSET,
    video_input_id: Union[Unset, UUID] = UNSET,
) -> Optional[Union[VideoStreamInputsOrgListResponseDefault, VideoStreamInputsOrgListVideoStreamInputsResponse]]:
    """List available video inputs for an organization

     Display the list of video inputs for an organization. This will only display inputs for matches in
    the future and from 12 hours in the past that have not been completed/cancelled.

    Args:
        organization_id (str):  Example: b1a23.
        added (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:10:48.
        competition_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        external (Union[Unset, str]):  Example: entityId,personId.
        feed_type (Union[Unset, VideoStreamInputsOrgListFeedType]):  Example: PRIMARY.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        fixture_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        from_time_local (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        from_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        hide_null (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        locale (Union[Unset, str]):  Example: fr_FR.
        offset (Union[Unset, int]):  Example: 10.
        provider (Union[Unset, str]):  Example: Test Provider.
        season_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        source_number (Union[Unset, int]):  Example: 1.
        to_time_local (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        to_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        updated (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:11:48.
        venue_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        video_input_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[VideoStreamInputsOrgListResponseDefault, VideoStreamInputsOrgListVideoStreamInputsResponse]
    """

    return (
        await asyncio_detailed(
            organization_id=organization_id,
            client=client,
            added=added,
            competition_id=competition_id,
            external=external,
            feed_type=feed_type,
            fields=fields,
            fixture_id=fixture_id,
            from_time_local=from_time_local,
            from_time_utc=from_time_utc,
            hide_null=hide_null,
            include=include,
            limit=limit,
            locale=locale,
            offset=offset,
            provider=provider,
            season_id=season_id,
            source_number=source_number,
            to_time_local=to_time_local,
            to_time_utc=to_time_utc,
            updated=updated,
            venue_id=venue_id,
            video_input_id=video_input_id,
        )
    ).parsed



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define

from ..models.series_model_season_series_competitor_series_result import SeriesModelSeasonSeriesCompetitorSeriesResult
from ..types import UNSET, Unset

T = TypeVar("T", bound="SeriesModelSeasonSeriesCompetitor")


@_attrs_define
class SeriesModelSeasonSeriesCompetitor:
    """
    Attributes:
        entity_id (Union[Unset, str]): The uuid of the entity
        person_id (Union[Unset, str]): The uuid of the person
        conference_id (Union[Unset, str]): The uuid of the conference the competitor represents
        division_id (Union[Unset, str]): The uuid of the conference the competitor represents
        pre_series_ranking (Union[Unset, float]): The rank of the competitor coming into the series
        string_record (Union[Unset, float]): String record of the competitor
        series_wins (Union[Unset, float]): Number of wins in the series for the competitor
        series_losses (Union[Unset, float]): Number of losses in the series for the competitor
        series_draws (Union[Unset, float]): Number of draws in the series for the competitor
        series_result (Union[Unset, SeriesModelSeasonSeriesCompetitorSeriesResult]): Result for the competitor in the
            series
    """

    entity_id: Union[Unset, str] = UNSET
    person_id: Union[Unset, str] = UNSET
    conference_id: Union[Unset, str] = UNSET
    division_id: Union[Unset, str] = UNSET
    pre_series_ranking: Union[Unset, float] = UNSET
    string_record: Union[Unset, float] = UNSET
    series_wins: Union[Unset, float] = UNSET
    series_losses: Union[Unset, float] = UNSET
    series_draws: Union[Unset, float] = UNSET
    series_result: Union[Unset, SeriesModelSeasonSeriesCompetitorSeriesResult] = UNSET

    def to_dict(self) -> dict[str, Any]:
        entity_id = self.entity_id

        person_id = self.person_id

        conference_id = self.conference_id

        division_id = self.division_id

        pre_series_ranking = self.pre_series_ranking

        string_record = self.string_record

        series_wins = self.series_wins

        series_losses = self.series_losses

        series_draws = self.series_draws

        series_result: Union[Unset, str] = UNSET
        if not isinstance(self.series_result, Unset):
            series_result = self.series_result.value

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if entity_id is not UNSET:
            field_dict["entityId"] = entity_id
        if person_id is not UNSET:
            field_dict["personId"] = person_id
        if conference_id is not UNSET:
            field_dict["conferenceId"] = conference_id
        if division_id is not UNSET:
            field_dict["divisionId"] = division_id
        if pre_series_ranking is not UNSET:
            field_dict["preSeriesRanking"] = pre_series_ranking
        if string_record is not UNSET:
            field_dict["stringRecord"] = string_record
        if series_wins is not UNSET:
            field_dict["seriesWins"] = series_wins
        if series_losses is not UNSET:
            field_dict["seriesLosses"] = series_losses
        if series_draws is not UNSET:
            field_dict["seriesDraws"] = series_draws
        if series_result is not UNSET:
            field_dict["seriesResult"] = series_result

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        entity_id = d.pop("entityId", UNSET)

        person_id = d.pop("personId", UNSET)

        conference_id = d.pop("conferenceId", UNSET)

        division_id = d.pop("divisionId", UNSET)

        pre_series_ranking = d.pop("preSeriesRanking", UNSET)

        string_record = d.pop("stringRecord", UNSET)

        series_wins = d.pop("seriesWins", UNSET)

        series_losses = d.pop("seriesLosses", UNSET)

        series_draws = d.pop("seriesDraws", UNSET)

        _series_result = d.pop("seriesResult", UNSET)
        series_result: Union[Unset, SeriesModelSeasonSeriesCompetitorSeriesResult]
        if isinstance(_series_result, Unset):
            series_result = UNSET
        else:
            series_result = SeriesModelSeasonSeriesCompetitorSeriesResult(_series_result)

        series_model_season_series_competitor = cls(
            entity_id=entity_id,
            person_id=person_id,
            conference_id=conference_id,
            division_id=division_id,
            pre_series_ranking=pre_series_ranking,
            string_record=string_record,
            series_wins=series_wins,
            series_losses=series_losses,
            series_draws=series_draws,
            series_result=series_result,
        )

        return series_model_season_series_competitor



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.standing_progressions_model_organization import StandingProgressionsModelOrganization
    from ..models.standing_progressions_model_pool import StandingProgressionsModelPool
    from ..models.standing_progressions_model_season import StandingProgressionsModelSeason
    from ..models.standing_progressions_model_stage import StandingProgressionsModelStage


T = TypeVar("T", bound="StandingProgressionsModel")


@_attrs_define
class StandingProgressionsModel:
    """
    Attributes:
        standing_progression_id (Union[Unset, UUID]): The unique identifier of the progression Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, StandingProgressionsModelOrganization]): The organization that this standing
            progressions belongs to
        season_id (Union[Unset, UUID]): The unique identifier of the season Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season (Union[Unset, StandingProgressionsModelSeason]): The season linked to this record
        name_local (Union[None, Unset, str]): The name of the standing progressions in the
            [local](#section/Introduction/Character-Sets-and-Names) language Example: Test season.
        name_latin (Union[None, Unset, str]): The name of the standing progressions in
            [latin](#section/Introduction/Character-Sets-and-Names) characters Example: Test season.
        stage_code (Union[None, Unset, str]): A unique code for the stage. (Unique for season) Example: ST1.
        stage (Union[Unset, StandingProgressionsModelStage]): The stage that is related to this record
        pool_code (Union[None, Unset, str]): A unique code for the pool. (Unique for season) Example: P1.
        pool (Union[Unset, StandingProgressionsModelPool]): The pool that is related to this record
        fixture_ids (Union[Unset, list[UUID]]):
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    standing_progression_id: Union[Unset, UUID] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "StandingProgressionsModelOrganization"] = UNSET
    season_id: Union[Unset, UUID] = UNSET
    season: Union[Unset, "StandingProgressionsModelSeason"] = UNSET
    name_local: Union[None, Unset, str] = UNSET
    name_latin: Union[None, Unset, str] = UNSET
    stage_code: Union[None, Unset, str] = UNSET
    stage: Union[Unset, "StandingProgressionsModelStage"] = UNSET
    pool_code: Union[None, Unset, str] = UNSET
    pool: Union[Unset, "StandingProgressionsModelPool"] = UNSET
    fixture_ids: Union[Unset, list[UUID]] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        standing_progression_id: Union[Unset, str] = UNSET
        if not isinstance(self.standing_progression_id, Unset):
            standing_progression_id = str(self.standing_progression_id)

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        season_id: Union[Unset, str] = UNSET
        if not isinstance(self.season_id, Unset):
            season_id = str(self.season_id)

        season: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.season, Unset):
            season = self.season.to_dict()

        name_local: Union[None, Unset, str]
        if isinstance(self.name_local, Unset):
            name_local = UNSET
        else:
            name_local = self.name_local

        name_latin: Union[None, Unset, str]
        if isinstance(self.name_latin, Unset):
            name_latin = UNSET
        else:
            name_latin = self.name_latin

        stage_code: Union[None, Unset, str]
        if isinstance(self.stage_code, Unset):
            stage_code = UNSET
        else:
            stage_code = self.stage_code

        stage: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.stage, Unset):
            stage = self.stage.to_dict()

        pool_code: Union[None, Unset, str]
        if isinstance(self.pool_code, Unset):
            pool_code = UNSET
        else:
            pool_code = self.pool_code

        pool: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.pool, Unset):
            pool = self.pool.to_dict()

        fixture_ids: Union[Unset, list[str]] = UNSET
        if not isinstance(self.fixture_ids, Unset):
            fixture_ids = []
            for fixture_ids_item_data in self.fixture_ids:
                fixture_ids_item = str(fixture_ids_item_data)
                fixture_ids.append(fixture_ids_item)

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if standing_progression_id is not UNSET:
            field_dict["standingProgressionId"] = standing_progression_id
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if season_id is not UNSET:
            field_dict["seasonId"] = season_id
        if season is not UNSET:
            field_dict["season"] = season
        if name_local is not UNSET:
            field_dict["nameLocal"] = name_local
        if name_latin is not UNSET:
            field_dict["nameLatin"] = name_latin
        if stage_code is not UNSET:
            field_dict["stageCode"] = stage_code
        if stage is not UNSET:
            field_dict["stage"] = stage
        if pool_code is not UNSET:
            field_dict["poolCode"] = pool_code
        if pool is not UNSET:
            field_dict["pool"] = pool
        if fixture_ids is not UNSET:
            field_dict["fixtureIds"] = fixture_ids
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.standing_progressions_model_organization import StandingProgressionsModelOrganization
        from ..models.standing_progressions_model_pool import StandingProgressionsModelPool
        from ..models.standing_progressions_model_season import StandingProgressionsModelSeason
        from ..models.standing_progressions_model_stage import StandingProgressionsModelStage

        d = dict(src_dict)
        _standing_progression_id = d.pop("standingProgressionId", UNSET)
        standing_progression_id: Union[Unset, UUID]
        if isinstance(_standing_progression_id, Unset):
            standing_progression_id = UNSET
        else:
            standing_progression_id = UUID(_standing_progression_id)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, StandingProgressionsModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = StandingProgressionsModelOrganization.from_dict(_organization)

        _season_id = d.pop("seasonId", UNSET)
        season_id: Union[Unset, UUID]
        if isinstance(_season_id, Unset):
            season_id = UNSET
        else:
            season_id = UUID(_season_id)

        _season = d.pop("season", UNSET)
        season: Union[Unset, StandingProgressionsModelSeason]
        if isinstance(_season, Unset):
            season = UNSET
        else:
            season = StandingProgressionsModelSeason.from_dict(_season)

        def _parse_name_local(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_local = _parse_name_local(d.pop("nameLocal", UNSET))

        def _parse_name_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_latin = _parse_name_latin(d.pop("nameLatin", UNSET))

        def _parse_stage_code(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        stage_code = _parse_stage_code(d.pop("stageCode", UNSET))

        _stage = d.pop("stage", UNSET)
        stage: Union[Unset, StandingProgressionsModelStage]
        if isinstance(_stage, Unset):
            stage = UNSET
        else:
            stage = StandingProgressionsModelStage.from_dict(_stage)

        def _parse_pool_code(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        pool_code = _parse_pool_code(d.pop("poolCode", UNSET))

        _pool = d.pop("pool", UNSET)
        pool: Union[Unset, StandingProgressionsModelPool]
        if isinstance(_pool, Unset):
            pool = UNSET
        else:
            pool = StandingProgressionsModelPool.from_dict(_pool)

        fixture_ids = []
        _fixture_ids = d.pop("fixtureIds", UNSET)
        for fixture_ids_item_data in _fixture_ids or []:
            fixture_ids_item = UUID(fixture_ids_item_data)

            fixture_ids.append(fixture_ids_item)

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        standing_progressions_model = cls(
            standing_progression_id=standing_progression_id,
            organization_id=organization_id,
            organization=organization,
            season_id=season_id,
            season=season,
            name_local=name_local,
            name_latin=name_latin,
            stage_code=stage_code,
            stage=stage,
            pool_code=pool_code,
            pool=pool,
            fixture_ids=fixture_ids,
            updated=updated,
            added=added,
        )

        return standing_progressions_model



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="SiteModelSiteAddress")


@_attrs_define
class SiteModelSiteAddress:
    """Street Address for the site

    Attributes:
        address1 (Union[None, Unset, str]): First line of the address
        address2 (Union[None, Unset, str]): Second line of the address
        address3 (Union[None, Unset, str]): Third line of the address
        city (Union[None, Unset, str]): The city/suburb of the address
        state (Union[None, Unset, str]): The state of the address
        postal_code (Union[None, Unset, str]): The postal code for the address
        country_code (Union[None, Unset, str]): ISO Country code of the address.  We recommend you use ISO-3166-1:alpha3
            (upper case) values where available.
        longitude (Union[None, Unset, float]):
        latitude (Union[None, Unset, float]):
    """

    address1: Union[None, Unset, str] = UNSET
    address2: Union[None, Unset, str] = UNSET
    address3: Union[None, Unset, str] = UNSET
    city: Union[None, Unset, str] = UNSET
    state: Union[None, Unset, str] = UNSET
    postal_code: Union[None, Unset, str] = UNSET
    country_code: Union[None, Unset, str] = UNSET
    longitude: Union[None, Unset, float] = UNSET
    latitude: Union[None, Unset, float] = UNSET

    def to_dict(self) -> dict[str, Any]:
        address1: Union[None, Unset, str]
        if isinstance(self.address1, Unset):
            address1 = UNSET
        else:
            address1 = self.address1

        address2: Union[None, Unset, str]
        if isinstance(self.address2, Unset):
            address2 = UNSET
        else:
            address2 = self.address2

        address3: Union[None, Unset, str]
        if isinstance(self.address3, Unset):
            address3 = UNSET
        else:
            address3 = self.address3

        city: Union[None, Unset, str]
        if isinstance(self.city, Unset):
            city = UNSET
        else:
            city = self.city

        state: Union[None, Unset, str]
        if isinstance(self.state, Unset):
            state = UNSET
        else:
            state = self.state

        postal_code: Union[None, Unset, str]
        if isinstance(self.postal_code, Unset):
            postal_code = UNSET
        else:
            postal_code = self.postal_code

        country_code: Union[None, Unset, str]
        if isinstance(self.country_code, Unset):
            country_code = UNSET
        else:
            country_code = self.country_code

        longitude: Union[None, Unset, float]
        if isinstance(self.longitude, Unset):
            longitude = UNSET
        else:
            longitude = self.longitude

        latitude: Union[None, Unset, float]
        if isinstance(self.latitude, Unset):
            latitude = UNSET
        else:
            latitude = self.latitude

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if address1 is not UNSET:
            field_dict["address1"] = address1
        if address2 is not UNSET:
            field_dict["address2"] = address2
        if address3 is not UNSET:
            field_dict["address3"] = address3
        if city is not UNSET:
            field_dict["city"] = city
        if state is not UNSET:
            field_dict["state"] = state
        if postal_code is not UNSET:
            field_dict["postalCode"] = postal_code
        if country_code is not UNSET:
            field_dict["countryCode"] = country_code
        if longitude is not UNSET:
            field_dict["longitude"] = longitude
        if latitude is not UNSET:
            field_dict["latitude"] = latitude

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)

        def _parse_address1(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        address1 = _parse_address1(d.pop("address1", UNSET))

        def _parse_address2(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        address2 = _parse_address2(d.pop("address2", UNSET))

        def _parse_address3(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        address3 = _parse_address3(d.pop("address3", UNSET))

        def _parse_city(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        city = _parse_city(d.pop("city", UNSET))

        def _parse_state(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        state = _parse_state(d.pop("state", UNSET))

        def _parse_postal_code(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        postal_code = _parse_postal_code(d.pop("postalCode", UNSET))

        def _parse_country_code(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        country_code = _parse_country_code(d.pop("countryCode", UNSET))

        def _parse_longitude(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        longitude = _parse_longitude(d.pop("longitude", UNSET))

        def _parse_latitude(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        latitude = _parse_latitude(d.pop("latitude", UNSET))

        site_model_site_address = cls(
            address1=address1,
            address2=address2,
            address3=address3,
            city=city,
            state=state,
            postal_code=postal_code,
            country_code=country_code,
            longitude=longitude,
            latitude=latitude,
        )

        return site_model_site_address



from enum import Enum


class StandingAdjustmentModelAdjustmentGroup(str, Enum):
    IN_CONFERENCE = "IN_CONFERENCE"
    IN_DIVISION = "IN_DIVISION"
    OUT_CONFERENCE = "OUT_CONFERENCE"
    OUT_DIVISION = "OUT_DIVISION"
    OVERALL = "OVERALL"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class CareerPersonRepresentationalStatisticsModelOrganizationResourceType(str, Enum):
    ORGANIZATIONS = "organizations"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class StandingAdjustmentModelAdjustmentField(str, Enum):
    BYES = "byes"
    DRAWS = "draws"
    DRAWSAWAY = "drawsAway"
    DRAWSHOME = "drawsHome"
    FORFEITSGIVEN = "forfeitsGiven"
    FORFEITSWONBY = "forfeitsWonBy"
    HIGHESTSCOREAGAINST = "highestScoreAgainst"
    HIGHESTSCOREAGAINSTAWAY = "highestScoreAgainstAway"
    HIGHESTSCOREAGAINSTHOME = "highestScoreAgainstHome"
    HIGHESTSCOREFOR = "highestScoreFor"
    HIGHESTSCOREFORAWAY = "highestScoreForAway"
    HIGHESTSCOREFORHOME = "highestScoreForHome"
    LOSSES = "losses"
    LOSSESAWAY = "lossesAway"
    LOSSESHOME = "lossesHome"
    LOWESTSCOREAGAINST = "lowestScoreAgainst"
    LOWESTSCOREAGAINSTAWAY = "lowestScoreAgainstAway"
    LOWESTSCOREAGAINSTHOME = "lowestScoreAgainstHome"
    LOWESTSCOREFOR = "lowestScoreFor"
    LOWESTSCOREFORAWAY = "lowestScoreForAway"
    LOWESTSCOREFORHOME = "lowestScoreForHome"
    PERCENTAGE = "percentage"
    PERCENTAGEAWAY = "percentageAway"
    PERCENTAGEHOME = "percentageHome"
    PLAYED = "played"
    PLAYEDAWAY = "playedAway"
    PLAYEDHOME = "playedHome"
    POINTDIFFERENCE = "pointDifference"
    POINTDIFFERENCEAWAY = "pointDifferenceAway"
    POINTDIFFERENCEHOME = "pointDifferenceHome"
    POSITION = "position"
    SCOREDAGAINST = "scoredAgainst"
    SCOREDAGAINSTAWAY = "scoredAgainstAway"
    SCOREDAGAINSTHOME = "scoredAgainstHome"
    SCOREDFOR = "scoredFor"
    SCOREDFORAWAY = "scoredForAway"
    SCOREDFORHOME = "scoredForHome"
    STANDINGPOINTS = "standingPoints"
    STANDINGPOINTSAWAY = "standingPointsAway"
    STANDINGPOINTSGIVEN = "standingPointsGiven"
    STANDINGPOINTSHOME = "standingPointsHome"
    STREAK = "streak"
    STREAKAWAY = "streakAway"
    STREAKHOME = "streakHome"
    WASHOUTS = "washouts"
    WINPERCENTAGE = "winPercentage"
    WINPERCENTAGEAWAY = "winPercentageAway"
    WINPERCENTAGEHOME = "winPercentageHome"
    WINS = "wins"
    WINSAWAY = "winsAway"
    WINSHOME = "winsHome"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class MatchTeamsModelResultStatus(str, Enum):
    CONFIRMED = "CONFIRMED"
    DID_NOT_FINISH = "DID_NOT_FINISH"
    DID_NOT_START = "DID_NOT_START"
    DISQUALIFIED = "DISQUALIFIED"
    FORFEITED = "FORFEITED"
    IN_PROGRESS = "IN_PROGRESS"
    SCHEDULED = "SCHEDULED"
    WITHDRAWN = "WITHDRAWN"
    WON_BY_FORFEIT = "WON_BY_FORFEIT"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class StandingConfigurationsModelStandingConfigurationHeadToHeadResolutionSortDirection(str, Enum):
    ASC = "ASC"
    DESC = "DESC"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.season_venues_model_organization import SeasonVenuesModelOrganization
    from ..models.season_venues_model_season import SeasonVenuesModelSeason
    from ..models.season_venues_model_season_venues_address import SeasonVenuesModelSeasonVenuesAddress
    from ..models.season_venues_model_site import SeasonVenuesModelSite
    from ..models.season_venues_model_social_media import SeasonVenuesModelSocialMedia


T = TypeVar("T", bound="SeasonVenuesModel")


@_attrs_define
class SeasonVenuesModel:
    """
    Attributes:
        season_id (Union[Unset, UUID]): The unique identifier of the season Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season (Union[Unset, SeasonVenuesModelSeason]): The season linked to this record
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, SeasonVenuesModelOrganization]): The organization that this season venues belongs to
        venue_id (Union[Unset, UUID]): The unique identifier of the venue Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        site_id (Union[None, UUID, Unset]): The site that this season venues belongs to Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        site (Union[Unset, SeasonVenuesModelSite]): The site that this season venues belongs to
        abbreviation_local (Union[None, Unset, str]): An abbreviation/short name in the
            [local](#section/Introduction/Character-Sets-and-Names) language Example: NFA.
        name_local (Union[Unset, str]): The name of the season venues in the [local](#section/Introduction/Character-
            Sets-and-Names) language Example: Test name local.
        alternate_name_local (Union[None, Unset, str]): The alternate name of the venue, in Local Language Example: Test
            venue.
        abbreviation_latin (Union[None, Unset, str]): An abbreviation/short name in
            [latin](#section/Introduction/Character-Sets-and-Names) characters Example: NFA.
        name_latin (Union[None, Unset, str]): The name of the season venues in [latin](#section/Introduction/Character-
            Sets-and-Names) characters Example: Test name latin .
        alternate_name_latin (Union[None, Unset, str]): The alternate name of the venue, in Latin characters Example:
            Test venue.
        country_code (Union[None, Unset, str]): Country code of the season venues. We recommend you use
            ISO-3166-1:alpha3 (upper case) values where available. Example: USA.
        timezone (Union[Unset, str]): Timezone of the venue.  The name of the zone as defined by the IANA TZ database.
            https://en.wikipedia.org/wiki/List_of_tz_database_time_zones Example: Australia/Sydney.
        address (Union['SeasonVenuesModelSeasonVenuesAddress', None, Unset]): Street Address for the season venues
        social (Union['SeasonVenuesModelSocialMedia', None, Unset]): Social Media contacts
        external_id (Union[None, Unset, str]): The Id of the data as set by the provider of the data Example: A123.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    season_id: Union[Unset, UUID] = UNSET
    season: Union[Unset, "SeasonVenuesModelSeason"] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "SeasonVenuesModelOrganization"] = UNSET
    venue_id: Union[Unset, UUID] = UNSET
    site_id: Union[None, UUID, Unset] = UNSET
    site: Union[Unset, "SeasonVenuesModelSite"] = UNSET
    abbreviation_local: Union[None, Unset, str] = UNSET
    name_local: Union[Unset, str] = UNSET
    alternate_name_local: Union[None, Unset, str] = UNSET
    abbreviation_latin: Union[None, Unset, str] = UNSET
    name_latin: Union[None, Unset, str] = UNSET
    alternate_name_latin: Union[None, Unset, str] = UNSET
    country_code: Union[None, Unset, str] = UNSET
    timezone: Union[Unset, str] = UNSET
    address: Union["SeasonVenuesModelSeasonVenuesAddress", None, Unset] = UNSET
    social: Union["SeasonVenuesModelSocialMedia", None, Unset] = UNSET
    external_id: Union[None, Unset, str] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        from ..models.season_venues_model_season_venues_address import SeasonVenuesModelSeasonVenuesAddress
        from ..models.season_venues_model_social_media import SeasonVenuesModelSocialMedia

        season_id: Union[Unset, str] = UNSET
        if not isinstance(self.season_id, Unset):
            season_id = str(self.season_id)

        season: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.season, Unset):
            season = self.season.to_dict()

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        venue_id: Union[Unset, str] = UNSET
        if not isinstance(self.venue_id, Unset):
            venue_id = str(self.venue_id)

        site_id: Union[None, Unset, str]
        if isinstance(self.site_id, Unset):
            site_id = UNSET
        elif isinstance(self.site_id, UUID):
            site_id = str(self.site_id)
        else:
            site_id = self.site_id

        site: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.site, Unset):
            site = self.site.to_dict()

        abbreviation_local: Union[None, Unset, str]
        if isinstance(self.abbreviation_local, Unset):
            abbreviation_local = UNSET
        else:
            abbreviation_local = self.abbreviation_local

        name_local = self.name_local

        alternate_name_local: Union[None, Unset, str]
        if isinstance(self.alternate_name_local, Unset):
            alternate_name_local = UNSET
        else:
            alternate_name_local = self.alternate_name_local

        abbreviation_latin: Union[None, Unset, str]
        if isinstance(self.abbreviation_latin, Unset):
            abbreviation_latin = UNSET
        else:
            abbreviation_latin = self.abbreviation_latin

        name_latin: Union[None, Unset, str]
        if isinstance(self.name_latin, Unset):
            name_latin = UNSET
        else:
            name_latin = self.name_latin

        alternate_name_latin: Union[None, Unset, str]
        if isinstance(self.alternate_name_latin, Unset):
            alternate_name_latin = UNSET
        else:
            alternate_name_latin = self.alternate_name_latin

        country_code: Union[None, Unset, str]
        if isinstance(self.country_code, Unset):
            country_code = UNSET
        else:
            country_code = self.country_code

        timezone = self.timezone

        address: Union[None, Unset, dict[str, Any]]
        if isinstance(self.address, Unset):
            address = UNSET
        elif isinstance(self.address, SeasonVenuesModelSeasonVenuesAddress):
            address = self.address.to_dict()
        else:
            address = self.address

        social: Union[None, Unset, dict[str, Any]]
        if isinstance(self.social, Unset):
            social = UNSET
        elif isinstance(self.social, SeasonVenuesModelSocialMedia):
            social = self.social.to_dict()
        else:
            social = self.social

        external_id: Union[None, Unset, str]
        if isinstance(self.external_id, Unset):
            external_id = UNSET
        else:
            external_id = self.external_id

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if season_id is not UNSET:
            field_dict["seasonId"] = season_id
        if season is not UNSET:
            field_dict["season"] = season
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if venue_id is not UNSET:
            field_dict["venueId"] = venue_id
        if site_id is not UNSET:
            field_dict["siteId"] = site_id
        if site is not UNSET:
            field_dict["site"] = site
        if abbreviation_local is not UNSET:
            field_dict["abbreviationLocal"] = abbreviation_local
        if name_local is not UNSET:
            field_dict["nameLocal"] = name_local
        if alternate_name_local is not UNSET:
            field_dict["alternateNameLocal"] = alternate_name_local
        if abbreviation_latin is not UNSET:
            field_dict["abbreviationLatin"] = abbreviation_latin
        if name_latin is not UNSET:
            field_dict["nameLatin"] = name_latin
        if alternate_name_latin is not UNSET:
            field_dict["alternateNameLatin"] = alternate_name_latin
        if country_code is not UNSET:
            field_dict["countryCode"] = country_code
        if timezone is not UNSET:
            field_dict["timezone"] = timezone
        if address is not UNSET:
            field_dict["address"] = address
        if social is not UNSET:
            field_dict["social"] = social
        if external_id is not UNSET:
            field_dict["externalId"] = external_id
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.season_venues_model_organization import SeasonVenuesModelOrganization
        from ..models.season_venues_model_season import SeasonVenuesModelSeason
        from ..models.season_venues_model_season_venues_address import SeasonVenuesModelSeasonVenuesAddress
        from ..models.season_venues_model_site import SeasonVenuesModelSite
        from ..models.season_venues_model_social_media import SeasonVenuesModelSocialMedia

        d = dict(src_dict)
        _season_id = d.pop("seasonId", UNSET)
        season_id: Union[Unset, UUID]
        if isinstance(_season_id, Unset):
            season_id = UNSET
        else:
            season_id = UUID(_season_id)

        _season = d.pop("season", UNSET)
        season: Union[Unset, SeasonVenuesModelSeason]
        if isinstance(_season, Unset):
            season = UNSET
        else:
            season = SeasonVenuesModelSeason.from_dict(_season)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, SeasonVenuesModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = SeasonVenuesModelOrganization.from_dict(_organization)

        _venue_id = d.pop("venueId", UNSET)
        venue_id: Union[Unset, UUID]
        if isinstance(_venue_id, Unset):
            venue_id = UNSET
        else:
            venue_id = UUID(_venue_id)

        def _parse_site_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                site_id_type_0 = UUID(data)

                return site_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        site_id = _parse_site_id(d.pop("siteId", UNSET))

        _site = d.pop("site", UNSET)
        site: Union[Unset, SeasonVenuesModelSite]
        if isinstance(_site, Unset):
            site = UNSET
        else:
            site = SeasonVenuesModelSite.from_dict(_site)

        def _parse_abbreviation_local(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        abbreviation_local = _parse_abbreviation_local(d.pop("abbreviationLocal", UNSET))

        name_local = d.pop("nameLocal", UNSET)

        def _parse_alternate_name_local(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        alternate_name_local = _parse_alternate_name_local(d.pop("alternateNameLocal", UNSET))

        def _parse_abbreviation_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        abbreviation_latin = _parse_abbreviation_latin(d.pop("abbreviationLatin", UNSET))

        def _parse_name_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_latin = _parse_name_latin(d.pop("nameLatin", UNSET))

        def _parse_alternate_name_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        alternate_name_latin = _parse_alternate_name_latin(d.pop("alternateNameLatin", UNSET))

        def _parse_country_code(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        country_code = _parse_country_code(d.pop("countryCode", UNSET))

        timezone = d.pop("timezone", UNSET)

        def _parse_address(data: object) -> Union["SeasonVenuesModelSeasonVenuesAddress", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                address_type_0 = SeasonVenuesModelSeasonVenuesAddress.from_dict(data)

                return address_type_0
            except:  # noqa: E722
                pass
            return cast(Union["SeasonVenuesModelSeasonVenuesAddress", None, Unset], data)

        address = _parse_address(d.pop("address", UNSET))

        def _parse_social(data: object) -> Union["SeasonVenuesModelSocialMedia", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                social_type_0 = SeasonVenuesModelSocialMedia.from_dict(data)

                return social_type_0
            except:  # noqa: E722
                pass
            return cast(Union["SeasonVenuesModelSocialMedia", None, Unset], data)

        social = _parse_social(d.pop("social", UNSET))

        def _parse_external_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        external_id = _parse_external_id(d.pop("externalId", UNSET))

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        season_venues_model = cls(
            season_id=season_id,
            season=season,
            organization_id=organization_id,
            organization=organization,
            venue_id=venue_id,
            site_id=site_id,
            site=site,
            abbreviation_local=abbreviation_local,
            name_local=name_local,
            alternate_name_local=alternate_name_local,
            abbreviation_latin=abbreviation_latin,
            name_latin=name_latin,
            alternate_name_latin=alternate_name_latin,
            country_code=country_code,
            timezone=timezone,
            address=address,
            social=social,
            external_id=external_id,
            updated=updated,
            added=added,
        )

        return season_venues_model



"""Error types for the Sportradar DataCore wrapper."""


class APIError(Exception):
    """Base class for all API wrapper errors."""


class AuthenticationError(APIError):
    """Authentication or token errors."""


class TransportError(APIError):
    """HTTP or network errors."""


class UnexpectedResponseError(APIError):
    """Unexpected or malformed API responses."""


class NotFoundError(APIError):
    """Requested entity not found."""


class ValidationError(APIError):
    """Invalid user input or parameters."""



from enum import Enum


class VideoFileModelStorageProviderType3Type1(str, Enum):
    AV_SPORTRADAR = "AV_SPORTRADAR"
    KEEMOTION = "KEEMOTION"
    SYNERGY = "SYNERGY"
    VALUE_0 = "5STREAM"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class ConductModelFineStatusType2Type1(str, Enum):
    CANCELLED = "CANCELLED"
    ISSUED = "ISSUED"
    OTHER = "OTHER"
    PAID = "PAID"
    UNPAID = "UNPAID"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.match_person_statistics_periods_model_period_id import MatchPersonStatisticsPeriodsModelPeriodId
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.match_person_statistics_periods_model_entity import MatchPersonStatisticsPeriodsModelEntity
    from ..models.match_person_statistics_periods_model_fixture import MatchPersonStatisticsPeriodsModelFixture
    from ..models.match_person_statistics_periods_model_organization import (
        MatchPersonStatisticsPeriodsModelOrganization,
    )
    from ..models.match_person_statistics_periods_model_person import MatchPersonStatisticsPeriodsModelPerson
    from ..models.match_person_statistics_periods_model_statistics import MatchPersonStatisticsPeriodsModelStatistics


T = TypeVar("T", bound="MatchPersonStatisticsPeriodsModel")


@_attrs_define
class MatchPersonStatisticsPeriodsModel:
    """
    Attributes:
        person_id (Union[Unset, UUID]): The unique identifier of the person Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        person (Union[Unset, MatchPersonStatisticsPeriodsModelPerson]): The person information
        entity_id (Union[None, UUID, Unset]): The unique identifier of the team Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity (Union[Unset, MatchPersonStatisticsPeriodsModelEntity]): The team information
        fixture_id (Union[Unset, UUID]): The unique identifier of the match Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        fixture (Union[Unset, MatchPersonStatisticsPeriodsModelFixture]): The match
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, MatchPersonStatisticsPeriodsModelOrganization]): The organization that this match
            person statistics periods belongs to
        statistics (Union[Unset, MatchPersonStatisticsPeriodsModelStatistics]):
        period_id (Union[Unset, MatchPersonStatisticsPeriodsModelPeriodId]): The identifier for the period
            >- `1` Period 1
            >- `2` Period 2
            >- `10` Extra time 1 period 1
            >- `11` Extra time 1 period 2
            >- `12` Extra time 2 period 1
            >- `13` Extra time 2 period 2
            >- `14` Shoot Out
        section (Union[Unset, str]): The section of the period (sub-period)
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    person_id: Union[Unset, UUID] = UNSET
    person: Union[Unset, "MatchPersonStatisticsPeriodsModelPerson"] = UNSET
    entity_id: Union[None, UUID, Unset] = UNSET
    entity: Union[Unset, "MatchPersonStatisticsPeriodsModelEntity"] = UNSET
    fixture_id: Union[Unset, UUID] = UNSET
    fixture: Union[Unset, "MatchPersonStatisticsPeriodsModelFixture"] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "MatchPersonStatisticsPeriodsModelOrganization"] = UNSET
    statistics: Union[Unset, "MatchPersonStatisticsPeriodsModelStatistics"] = UNSET
    period_id: Union[Unset, MatchPersonStatisticsPeriodsModelPeriodId] = UNSET
    section: Union[Unset, str] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        person_id: Union[Unset, str] = UNSET
        if not isinstance(self.person_id, Unset):
            person_id = str(self.person_id)

        person: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.person, Unset):
            person = self.person.to_dict()

        entity_id: Union[None, Unset, str]
        if isinstance(self.entity_id, Unset):
            entity_id = UNSET
        elif isinstance(self.entity_id, UUID):
            entity_id = str(self.entity_id)
        else:
            entity_id = self.entity_id

        entity: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.entity, Unset):
            entity = self.entity.to_dict()

        fixture_id: Union[Unset, str] = UNSET
        if not isinstance(self.fixture_id, Unset):
            fixture_id = str(self.fixture_id)

        fixture: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.fixture, Unset):
            fixture = self.fixture.to_dict()

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        statistics: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.statistics, Unset):
            statistics = self.statistics.to_dict()

        period_id: Union[Unset, int] = UNSET
        if not isinstance(self.period_id, Unset):
            period_id = self.period_id.value

        section = self.section

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if person_id is not UNSET:
            field_dict["personId"] = person_id
        if person is not UNSET:
            field_dict["person"] = person
        if entity_id is not UNSET:
            field_dict["entityId"] = entity_id
        if entity is not UNSET:
            field_dict["entity"] = entity
        if fixture_id is not UNSET:
            field_dict["fixtureId"] = fixture_id
        if fixture is not UNSET:
            field_dict["fixture"] = fixture
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if statistics is not UNSET:
            field_dict["statistics"] = statistics
        if period_id is not UNSET:
            field_dict["periodId"] = period_id
        if section is not UNSET:
            field_dict["section"] = section
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.match_person_statistics_periods_model_entity import MatchPersonStatisticsPeriodsModelEntity
        from ..models.match_person_statistics_periods_model_fixture import MatchPersonStatisticsPeriodsModelFixture
        from ..models.match_person_statistics_periods_model_organization import (
            MatchPersonStatisticsPeriodsModelOrganization,
        )
        from ..models.match_person_statistics_periods_model_person import MatchPersonStatisticsPeriodsModelPerson
        from ..models.match_person_statistics_periods_model_statistics import (
            MatchPersonStatisticsPeriodsModelStatistics,
        )

        d = dict(src_dict)
        _person_id = d.pop("personId", UNSET)
        person_id: Union[Unset, UUID]
        if isinstance(_person_id, Unset):
            person_id = UNSET
        else:
            person_id = UUID(_person_id)

        _person = d.pop("person", UNSET)
        person: Union[Unset, MatchPersonStatisticsPeriodsModelPerson]
        if isinstance(_person, Unset):
            person = UNSET
        else:
            person = MatchPersonStatisticsPeriodsModelPerson.from_dict(_person)

        def _parse_entity_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                entity_id_type_0 = UUID(data)

                return entity_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        entity_id = _parse_entity_id(d.pop("entityId", UNSET))

        _entity = d.pop("entity", UNSET)
        entity: Union[Unset, MatchPersonStatisticsPeriodsModelEntity]
        if isinstance(_entity, Unset):
            entity = UNSET
        else:
            entity = MatchPersonStatisticsPeriodsModelEntity.from_dict(_entity)

        _fixture_id = d.pop("fixtureId", UNSET)
        fixture_id: Union[Unset, UUID]
        if isinstance(_fixture_id, Unset):
            fixture_id = UNSET
        else:
            fixture_id = UUID(_fixture_id)

        _fixture = d.pop("fixture", UNSET)
        fixture: Union[Unset, MatchPersonStatisticsPeriodsModelFixture]
        if isinstance(_fixture, Unset):
            fixture = UNSET
        else:
            fixture = MatchPersonStatisticsPeriodsModelFixture.from_dict(_fixture)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, MatchPersonStatisticsPeriodsModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = MatchPersonStatisticsPeriodsModelOrganization.from_dict(_organization)

        _statistics = d.pop("statistics", UNSET)
        statistics: Union[Unset, MatchPersonStatisticsPeriodsModelStatistics]
        if isinstance(_statistics, Unset):
            statistics = UNSET
        else:
            statistics = MatchPersonStatisticsPeriodsModelStatistics.from_dict(_statistics)

        _period_id = d.pop("periodId", UNSET)
        period_id: Union[Unset, MatchPersonStatisticsPeriodsModelPeriodId]
        if isinstance(_period_id, Unset):
            period_id = UNSET
        else:
            period_id = MatchPersonStatisticsPeriodsModelPeriodId(_period_id)

        section = d.pop("section", UNSET)

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        match_person_statistics_periods_model = cls(
            person_id=person_id,
            person=person,
            entity_id=entity_id,
            entity=entity,
            fixture_id=fixture_id,
            fixture=fixture,
            organization_id=organization_id,
            organization=organization,
            statistics=statistics,
            period_id=period_id,
            section=section,
            updated=updated,
            added=added,
        )

        return match_person_statistics_periods_model



from enum import Enum


class TransfersListTransferType(str, Enum):
    DROPPED = "DROPPED"
    OTHER = "OTHER"
    PERMIT = "PERMIT"
    TRADE = "TRADE"
    TRANSFER = "TRANSFER"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class LeaderQualifierModelComparisonType(str, Enum):
    EQUAL = "EQUAL"
    GREATER_THAN = "GREATER_THAN"
    GREATER_THAN_EQUAL = "GREATER_THAN_EQUAL"
    LESS_THAN = "LESS_THAN"
    LESS_THAN_EQUAL = "LESS_THAN_EQUAL"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define

from ..models.season_model_promotion_relegation_rules_type_0_item_rule_type import (
    SeasonModelPromotionRelegationRulesType0ItemRuleType,
)

T = TypeVar("T", bound="SeasonModelPromotionRelegationRulesType0Item")


@_attrs_define
class SeasonModelPromotionRelegationRulesType0Item:
    """
    Attributes:
        rule_type (SeasonModelPromotionRelegationRulesType0ItemRuleType): Rule Type
        position (float): Standings Position
        value (str): Value to apply to Promotion or Relegation Example: DIV1.
    """

    rule_type: SeasonModelPromotionRelegationRulesType0ItemRuleType
    position: float
    value: str

    def to_dict(self) -> dict[str, Any]:
        rule_type = self.rule_type.value

        position = self.position

        value = self.value

        field_dict: dict[str, Any] = {}

        field_dict.update(
            {
                "ruleType": rule_type,
                "position": position,
                "value": value,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        rule_type = SeasonModelPromotionRelegationRulesType0ItemRuleType(d.pop("ruleType"))

        position = d.pop("position")

        value = d.pop("value")

        season_model_promotion_relegation_rules_type_0_item = cls(
            rule_type=rule_type,
            position=position,
            value=value,
        )

        return season_model_promotion_relegation_rules_type_0_item



from enum import Enum


class FixtureByCompetitionListDiscipline(str, Enum):
    BEACH = "BEACH"
    HOCKEY5S = "HOCKEY5S"
    INDOOR = "INDOOR"
    OUTDOOR = "OUTDOOR"
    PARAHOCKEY = "PARAHOCKEY"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union
from uuid import UUID

from attrs import define as _attrs_define

from ..models.season_entity_statistics_model_period_id import SeasonEntityStatisticsModelPeriodId
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.season_entity_statistics_model_competition import SeasonEntityStatisticsModelCompetition
    from ..models.season_entity_statistics_model_entity import SeasonEntityStatisticsModelEntity
    from ..models.season_entity_statistics_model_organization import SeasonEntityStatisticsModelOrganization
    from ..models.season_entity_statistics_model_season import SeasonEntityStatisticsModelSeason
    from ..models.season_entity_statistics_model_statistics import SeasonEntityStatisticsModelStatistics


T = TypeVar("T", bound="SeasonEntityStatisticsModel")


@_attrs_define
class SeasonEntityStatisticsModel:
    """
    Attributes:
        entity_id (Union[Unset, UUID]): The unique identifier of the team Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity (Union[Unset, SeasonEntityStatisticsModelEntity]): The team information
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, SeasonEntityStatisticsModelOrganization]): The organization that this season entity
            statistics belongs to
        season_id (Union[Unset, UUID]): The unique identifier of the season Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season (Union[Unset, SeasonEntityStatisticsModelSeason]): The season linked to this record
        competition_id (Union[Unset, UUID]): The unique identifier of the competition Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        competition (Union[Unset, SeasonEntityStatisticsModelCompetition]): The competition that this season belongs to
        period_id (Union[Unset, SeasonEntityStatisticsModelPeriodId]): The identifier for the period
            >- `1` Period 1
            >- `2` Period 2
            >- `10` Extra time 1 period 1
            >- `11` Extra time 1 period 2
            >- `12` Extra time 2 period 1
            >- `13` Extra time 2 period 2
            >- `14` Shoot Out
        statistics (Union[Unset, SeasonEntityStatisticsModelStatistics]):
    """

    entity_id: Union[Unset, UUID] = UNSET
    entity: Union[Unset, "SeasonEntityStatisticsModelEntity"] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "SeasonEntityStatisticsModelOrganization"] = UNSET
    season_id: Union[Unset, UUID] = UNSET
    season: Union[Unset, "SeasonEntityStatisticsModelSeason"] = UNSET
    competition_id: Union[Unset, UUID] = UNSET
    competition: Union[Unset, "SeasonEntityStatisticsModelCompetition"] = UNSET
    period_id: Union[Unset, SeasonEntityStatisticsModelPeriodId] = UNSET
    statistics: Union[Unset, "SeasonEntityStatisticsModelStatistics"] = UNSET

    def to_dict(self) -> dict[str, Any]:
        entity_id: Union[Unset, str] = UNSET
        if not isinstance(self.entity_id, Unset):
            entity_id = str(self.entity_id)

        entity: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.entity, Unset):
            entity = self.entity.to_dict()

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        season_id: Union[Unset, str] = UNSET
        if not isinstance(self.season_id, Unset):
            season_id = str(self.season_id)

        season: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.season, Unset):
            season = self.season.to_dict()

        competition_id: Union[Unset, str] = UNSET
        if not isinstance(self.competition_id, Unset):
            competition_id = str(self.competition_id)

        competition: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.competition, Unset):
            competition = self.competition.to_dict()

        period_id: Union[Unset, int] = UNSET
        if not isinstance(self.period_id, Unset):
            period_id = self.period_id.value

        statistics: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.statistics, Unset):
            statistics = self.statistics.to_dict()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if entity_id is not UNSET:
            field_dict["entityId"] = entity_id
        if entity is not UNSET:
            field_dict["entity"] = entity
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if season_id is not UNSET:
            field_dict["seasonId"] = season_id
        if season is not UNSET:
            field_dict["season"] = season
        if competition_id is not UNSET:
            field_dict["competitionId"] = competition_id
        if competition is not UNSET:
            field_dict["competition"] = competition
        if period_id is not UNSET:
            field_dict["periodId"] = period_id
        if statistics is not UNSET:
            field_dict["statistics"] = statistics

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.season_entity_statistics_model_competition import SeasonEntityStatisticsModelCompetition
        from ..models.season_entity_statistics_model_entity import SeasonEntityStatisticsModelEntity
        from ..models.season_entity_statistics_model_organization import SeasonEntityStatisticsModelOrganization
        from ..models.season_entity_statistics_model_season import SeasonEntityStatisticsModelSeason
        from ..models.season_entity_statistics_model_statistics import SeasonEntityStatisticsModelStatistics

        d = dict(src_dict)
        _entity_id = d.pop("entityId", UNSET)
        entity_id: Union[Unset, UUID]
        if isinstance(_entity_id, Unset):
            entity_id = UNSET
        else:
            entity_id = UUID(_entity_id)

        _entity = d.pop("entity", UNSET)
        entity: Union[Unset, SeasonEntityStatisticsModelEntity]
        if isinstance(_entity, Unset):
            entity = UNSET
        else:
            entity = SeasonEntityStatisticsModelEntity.from_dict(_entity)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, SeasonEntityStatisticsModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = SeasonEntityStatisticsModelOrganization.from_dict(_organization)

        _season_id = d.pop("seasonId", UNSET)
        season_id: Union[Unset, UUID]
        if isinstance(_season_id, Unset):
            season_id = UNSET
        else:
            season_id = UUID(_season_id)

        _season = d.pop("season", UNSET)
        season: Union[Unset, SeasonEntityStatisticsModelSeason]
        if isinstance(_season, Unset):
            season = UNSET
        else:
            season = SeasonEntityStatisticsModelSeason.from_dict(_season)

        _competition_id = d.pop("competitionId", UNSET)
        competition_id: Union[Unset, UUID]
        if isinstance(_competition_id, Unset):
            competition_id = UNSET
        else:
            competition_id = UUID(_competition_id)

        _competition = d.pop("competition", UNSET)
        competition: Union[Unset, SeasonEntityStatisticsModelCompetition]
        if isinstance(_competition, Unset):
            competition = UNSET
        else:
            competition = SeasonEntityStatisticsModelCompetition.from_dict(_competition)

        _period_id = d.pop("periodId", UNSET)
        period_id: Union[Unset, SeasonEntityStatisticsModelPeriodId]
        if isinstance(_period_id, Unset):
            period_id = UNSET
        else:
            period_id = SeasonEntityStatisticsModelPeriodId(_period_id)

        _statistics = d.pop("statistics", UNSET)
        statistics: Union[Unset, SeasonEntityStatisticsModelStatistics]
        if isinstance(_statistics, Unset):
            statistics = UNSET
        else:
            statistics = SeasonEntityStatisticsModelStatistics.from_dict(_statistics)

        season_entity_statistics_model = cls(
            entity_id=entity_id,
            entity=entity,
            organization_id=organization_id,
            organization=organization,
            season_id=season_id,
            season=season,
            competition_id=competition_id,
            competition=competition,
            period_id=period_id,
            statistics=statistics,
        )

        return season_entity_statistics_model



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.error_list_model_reason import ErrorListModelReason
from ..types import UNSET, Unset

T = TypeVar("T", bound="ErrorListModel")


@_attrs_define
class ErrorListModel:
    """
    Attributes:
        code (Union[Unset, int]): HTTP Error code indicating the type of error. Example: 400.
        reason (Union[Unset, ErrorListModelReason]): A short code indicating the type of error Example: INVALID_DATA.
        message (Union[Unset, str]): A message indicating the reason for the error Example: Field 'dob' must contain a
            valid date.
        row_number (Union[Unset, int]): The row number of the payload that cause the error Example: 1.
    """

    code: Union[Unset, int] = UNSET
    reason: Union[Unset, ErrorListModelReason] = UNSET
    message: Union[Unset, str] = UNSET
    row_number: Union[Unset, int] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        code = self.code

        reason: Union[Unset, str] = UNSET
        if not isinstance(self.reason, Unset):
            reason = self.reason.value

        message = self.message

        row_number = self.row_number

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if code is not UNSET:
            field_dict["code"] = code
        if reason is not UNSET:
            field_dict["reason"] = reason
        if message is not UNSET:
            field_dict["message"] = message
        if row_number is not UNSET:
            field_dict["rowNumber"] = row_number

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        code = d.pop("code", UNSET)

        _reason = d.pop("reason", UNSET)
        reason: Union[Unset, ErrorListModelReason]
        if isinstance(_reason, Unset):
            reason = UNSET
        else:
            reason = ErrorListModelReason(_reason)

        message = d.pop("message", UNSET)

        row_number = d.pop("rowNumber", UNSET)

        error_list_model = cls(
            code=code,
            reason=reason,
            message=message,
            row_number=row_number,
        )

        error_list_model.additional_properties = d
        return error_list_model

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.video_stream_outputs_model_content import VideoStreamOutputsModelContent
from ..models.video_stream_outputs_model_feed_type import VideoStreamOutputsModelFeedType
from ..models.video_stream_outputs_model_input_resolution import VideoStreamOutputsModelInputResolution
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.video_stream_outputs_model_competition import VideoStreamOutputsModelCompetition
    from ..models.video_stream_outputs_model_fixture import VideoStreamOutputsModelFixture
    from ..models.video_stream_outputs_model_organization import VideoStreamOutputsModelOrganization
    from ..models.video_stream_outputs_model_venue import VideoStreamOutputsModelVenue


T = TypeVar("T", bound="VideoStreamOutputsModel")


@_attrs_define
class VideoStreamOutputsModel:
    """
    Attributes:
        video_input_id (Union[Unset, UUID]): The unique identifier of the video input Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        master_venue_id (Union[Unset, UUID]): The unique identifier of the master venue Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, VideoStreamOutputsModelOrganization]): The organization that this Video Stream
            Outputs belongs to
        venue_id (Union[Unset, UUID]): The unique identifier of the venue Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        venue (Union[Unset, VideoStreamOutputsModelVenue]): The venue that this match belongs to
        competition_id (Union[Unset, UUID]): The unique identifier of the competition Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        competition (Union[Unset, VideoStreamOutputsModelCompetition]): The competition that this season belongs to
        fixture_id (Union[Unset, UUID]): The unique identifier of the match Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        fixture (Union[Unset, VideoStreamOutputsModelFixture]): The match
        provider (Union[Unset, str]): The code for the provider of the file Example: Test Provider.
        locale (Union[Unset, str]): The locale of the video Example: fr-FR.
        source_number (Union[Unset, int]): Unique identifier for the video source. This is unique for the
            provider/fixtureId/locale combination.  Unless the provider is supplying multiple sources per fixture/locale
            then this is normally 1. Default: 1. Example: 1.
        feed_type (Union[Unset, VideoStreamOutputsModelFeedType]): Type of video input
            >- `ADDITIONAL_ANGLE` Additional angle
            >- `LOW_LATENCY` Low Latency
            >- `PRIMARY` Primary
             Example: PRIMARY.
        input_resolution (Union[Unset, VideoStreamOutputsModelInputResolution]): The resolution of the video input
            >- `1080` 1920 x 1080
            >- `288` 512 x 288
            >- `720` 1280 x 720
             Example: 720.
        name (Union[Unset, str]): The name of the video source Example: Automated Capture Feed.
        content (Union[Unset, VideoStreamOutputsModelContent]): Content of the stream
            >- `CLEAN` Output signal is the same as the input signal
            >- `PROGRAM` Score overlays and other enhancements have been added to the stream
             Default: VideoStreamOutputsModelContent.CLEAN. Example: CLEAN.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
        audio_ambience (Union[Unset, bool]): Audio Ambience Example: True.
        audio_commentary (Union[Unset, bool]): Audio Commentary Example: True.
    """

    video_input_id: Union[Unset, UUID] = UNSET
    master_venue_id: Union[Unset, UUID] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "VideoStreamOutputsModelOrganization"] = UNSET
    venue_id: Union[Unset, UUID] = UNSET
    venue: Union[Unset, "VideoStreamOutputsModelVenue"] = UNSET
    competition_id: Union[Unset, UUID] = UNSET
    competition: Union[Unset, "VideoStreamOutputsModelCompetition"] = UNSET
    fixture_id: Union[Unset, UUID] = UNSET
    fixture: Union[Unset, "VideoStreamOutputsModelFixture"] = UNSET
    provider: Union[Unset, str] = UNSET
    locale: Union[Unset, str] = UNSET
    source_number: Union[Unset, int] = 1
    feed_type: Union[Unset, VideoStreamOutputsModelFeedType] = UNSET
    input_resolution: Union[Unset, VideoStreamOutputsModelInputResolution] = UNSET
    name: Union[Unset, str] = UNSET
    content: Union[Unset, VideoStreamOutputsModelContent] = VideoStreamOutputsModelContent.CLEAN
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET
    audio_ambience: Union[Unset, bool] = UNSET
    audio_commentary: Union[Unset, bool] = UNSET

    def to_dict(self) -> dict[str, Any]:
        video_input_id: Union[Unset, str] = UNSET
        if not isinstance(self.video_input_id, Unset):
            video_input_id = str(self.video_input_id)

        master_venue_id: Union[Unset, str] = UNSET
        if not isinstance(self.master_venue_id, Unset):
            master_venue_id = str(self.master_venue_id)

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        venue_id: Union[Unset, str] = UNSET
        if not isinstance(self.venue_id, Unset):
            venue_id = str(self.venue_id)

        venue: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.venue, Unset):
            venue = self.venue.to_dict()

        competition_id: Union[Unset, str] = UNSET
        if not isinstance(self.competition_id, Unset):
            competition_id = str(self.competition_id)

        competition: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.competition, Unset):
            competition = self.competition.to_dict()

        fixture_id: Union[Unset, str] = UNSET
        if not isinstance(self.fixture_id, Unset):
            fixture_id = str(self.fixture_id)

        fixture: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.fixture, Unset):
            fixture = self.fixture.to_dict()

        provider = self.provider

        locale = self.locale

        source_number = self.source_number

        feed_type: Union[Unset, str] = UNSET
        if not isinstance(self.feed_type, Unset):
            feed_type = self.feed_type.value

        input_resolution: Union[Unset, str] = UNSET
        if not isinstance(self.input_resolution, Unset):
            input_resolution = self.input_resolution.value

        name = self.name

        content: Union[Unset, str] = UNSET
        if not isinstance(self.content, Unset):
            content = self.content.value

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        audio_ambience = self.audio_ambience

        audio_commentary = self.audio_commentary

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if video_input_id is not UNSET:
            field_dict["videoInputId"] = video_input_id
        if master_venue_id is not UNSET:
            field_dict["masterVenueId"] = master_venue_id
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if venue_id is not UNSET:
            field_dict["venueId"] = venue_id
        if venue is not UNSET:
            field_dict["venue"] = venue
        if competition_id is not UNSET:
            field_dict["competitionId"] = competition_id
        if competition is not UNSET:
            field_dict["competition"] = competition
        if fixture_id is not UNSET:
            field_dict["fixtureId"] = fixture_id
        if fixture is not UNSET:
            field_dict["fixture"] = fixture
        if provider is not UNSET:
            field_dict["provider"] = provider
        if locale is not UNSET:
            field_dict["locale"] = locale
        if source_number is not UNSET:
            field_dict["sourceNumber"] = source_number
        if feed_type is not UNSET:
            field_dict["feedType"] = feed_type
        if input_resolution is not UNSET:
            field_dict["inputResolution"] = input_resolution
        if name is not UNSET:
            field_dict["name"] = name
        if content is not UNSET:
            field_dict["content"] = content
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added
        if audio_ambience is not UNSET:
            field_dict["audioAmbience"] = audio_ambience
        if audio_commentary is not UNSET:
            field_dict["audioCommentary"] = audio_commentary

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.video_stream_outputs_model_competition import VideoStreamOutputsModelCompetition
        from ..models.video_stream_outputs_model_fixture import VideoStreamOutputsModelFixture
        from ..models.video_stream_outputs_model_organization import VideoStreamOutputsModelOrganization
        from ..models.video_stream_outputs_model_venue import VideoStreamOutputsModelVenue

        d = dict(src_dict)
        _video_input_id = d.pop("videoInputId", UNSET)
        video_input_id: Union[Unset, UUID]
        if isinstance(_video_input_id, Unset):
            video_input_id = UNSET
        else:
            video_input_id = UUID(_video_input_id)

        _master_venue_id = d.pop("masterVenueId", UNSET)
        master_venue_id: Union[Unset, UUID]
        if isinstance(_master_venue_id, Unset):
            master_venue_id = UNSET
        else:
            master_venue_id = UUID(_master_venue_id)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, VideoStreamOutputsModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = VideoStreamOutputsModelOrganization.from_dict(_organization)

        _venue_id = d.pop("venueId", UNSET)
        venue_id: Union[Unset, UUID]
        if isinstance(_venue_id, Unset):
            venue_id = UNSET
        else:
            venue_id = UUID(_venue_id)

        _venue = d.pop("venue", UNSET)
        venue: Union[Unset, VideoStreamOutputsModelVenue]
        if isinstance(_venue, Unset):
            venue = UNSET
        else:
            venue = VideoStreamOutputsModelVenue.from_dict(_venue)

        _competition_id = d.pop("competitionId", UNSET)
        competition_id: Union[Unset, UUID]
        if isinstance(_competition_id, Unset):
            competition_id = UNSET
        else:
            competition_id = UUID(_competition_id)

        _competition = d.pop("competition", UNSET)
        competition: Union[Unset, VideoStreamOutputsModelCompetition]
        if isinstance(_competition, Unset):
            competition = UNSET
        else:
            competition = VideoStreamOutputsModelCompetition.from_dict(_competition)

        _fixture_id = d.pop("fixtureId", UNSET)
        fixture_id: Union[Unset, UUID]
        if isinstance(_fixture_id, Unset):
            fixture_id = UNSET
        else:
            fixture_id = UUID(_fixture_id)

        _fixture = d.pop("fixture", UNSET)
        fixture: Union[Unset, VideoStreamOutputsModelFixture]
        if isinstance(_fixture, Unset):
            fixture = UNSET
        else:
            fixture = VideoStreamOutputsModelFixture.from_dict(_fixture)

        provider = d.pop("provider", UNSET)

        locale = d.pop("locale", UNSET)

        source_number = d.pop("sourceNumber", UNSET)

        _feed_type = d.pop("feedType", UNSET)
        feed_type: Union[Unset, VideoStreamOutputsModelFeedType]
        if isinstance(_feed_type, Unset):
            feed_type = UNSET
        else:
            feed_type = VideoStreamOutputsModelFeedType(_feed_type)

        _input_resolution = d.pop("inputResolution", UNSET)
        input_resolution: Union[Unset, VideoStreamOutputsModelInputResolution]
        if isinstance(_input_resolution, Unset):
            input_resolution = UNSET
        else:
            input_resolution = VideoStreamOutputsModelInputResolution(_input_resolution)

        name = d.pop("name", UNSET)

        _content = d.pop("content", UNSET)
        content: Union[Unset, VideoStreamOutputsModelContent]
        if isinstance(_content, Unset):
            content = UNSET
        else:
            content = VideoStreamOutputsModelContent(_content)

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        audio_ambience = d.pop("audioAmbience", UNSET)

        audio_commentary = d.pop("audioCommentary", UNSET)

        video_stream_outputs_model = cls(
            video_input_id=video_input_id,
            master_venue_id=master_venue_id,
            organization_id=organization_id,
            organization=organization,
            venue_id=venue_id,
            venue=venue,
            competition_id=competition_id,
            competition=competition,
            fixture_id=fixture_id,
            fixture=fixture,
            provider=provider,
            locale=locale,
            source_number=source_number,
            feed_type=feed_type,
            input_resolution=input_resolution,
            name=name,
            content=content,
            updated=updated,
            added=added,
            audio_ambience=audio_ambience,
            audio_commentary=audio_commentary,
        )

        return video_stream_outputs_model
